# Population Averaging
Given a representative population sample, one could simply average these
graphs and use the average adjacency with the individual connectivity as features.

This transformer is intended for this case.

## Population Averaging Transform
::: photonai_graph.PopulationAveragingTransform.PopulationAveragingTransform.__init__
    rendering:
        show_root_toc_entry: False